@@ -109,7 +109,7 @@ def get_utcnow_datetime(microseconds=True):
         return ret.replace(microsecond=0)
 
 
-def is_same_time(*times, tollerance=1e-6, strip_tzinfo=False):
+def is_same_time(*times, tolerance=1e-6, strip_tzinfo=False):
     """Helper to do comparison between time points
 
     Time zone information gets stripped
@@ -118,8 +118,8 @@ def is_same_time(*times, tollerance=1e-6, strip_tzinfo=False):
 
     Parameters
     ----------
-    tollerance: float, optional
-      Seconds of difference between times to tollerate.  By default difference
+    tolerance: float, optional
+      Seconds of difference between times to tolerate.  By default difference
       up to a microsecond is ok
     """
     assert len(times) >= 2
@@ -130,10 +130,10 @@ def is_same_time(*times, tollerance=1e-6, strip_tzinfo=False):
     ]
 
     # we need to have all pairs
-    tollerance_dt = datetime.timedelta(seconds=tollerance)
+    tolerance_dt = datetime.timedelta(seconds=tolerance)
     return all(
         # if we subtract from smaller - we get negative days etc
-        (t1 - t2 if t1 > t2 else t2 - t1) <= tollerance_dt
+        (t1 - t2 if t1 > t2 else t2 - t1) <= tolerance_dt
         for (t1, t2) in itertools.combinations(norm_times, 2)
     )
 
@@ -618,26 +618,35 @@ def get_instance(dandi_instance_id):
         raise CliVersionTooOldError(our_version, minversion, bad_versions)
     if our_version in bad_versions:
         raise BadCliVersionError(our_version, minversion, bad_versions)
-    if server_info["services"].get("girder"):
+    # note: service: url, not a full record
+    services = {
+        name: (rec or {}).get(
+            "url"
+        )  # note: somehow was ending up with {"girder": None}
+        for name, rec in server_info.get("services", {}).items()
+    }
+    if services.get("girder"):
         return dandi_instance(
             metadata_version=0,
-            girder=server_info["services"].get("girder", {}).get("url"),
-            gui=server_info["services"].get("webui", {}).get("url"),
+            girder=services.get("girder"),
+            gui=services.get("webui"),
             redirector=redirector_url,
             api=None,
         )
-    elif server_info["services"].get("api"):
+    elif services.get("api"):
         return dandi_instance(
             metadata_version=1,
             girder=None,
-            gui=server_info["services"].get("webui", {}).get("url"),
+            gui=services.get("webui"),
             redirector=redirector_url,
-            api=server_info["services"].get("api", {}).get("url"),
+            api=services.get("api"),
         )
     else:
         raise RuntimeError(
             "redirector's server-info returned unknown set of services keys: "
-            + ", ".join(k for k, v in server_info["services"].items() if v is not None)
+            + ", ".join(
+                k for k, v in server_info.get("services", {}).items() if v is not None
+            )
         )
 
 
